@@ -22,6 +22,8 @@ from glashammer.utils.templating import create_template_environment
 from glashammer.utils import local, local_manager, EventManager, emit_event, \
     url_for, sibpath, Request
 
+from glashammer.utils.log import debug, warning
+
 
 
 def default_setup_func(app):
@@ -200,6 +202,12 @@ class GlashammerApplication(object):
         self.add_shared('glashammer', sibpath(__file__, 'shared'))
         self.add_middleware(SharedDataMiddleware, self._shared_exports)
 
+        # now the middleware for cleaning up things
+        self.add_middleware(local_manager.make_middleware)
+
+        # Keep this hanging around for introspection
+        self.shared_export_map = self._shared_exports
+
         del self._shared_exports
 
         # finalize the setup
@@ -208,11 +216,13 @@ class GlashammerApplication(object):
         emit_event('app-setup', self)
 
     def __call__(self, environ, start_response):
+        local.application = self
+        emit_event('wsgi-call')
+        emit_event('wsgi-env', environ)
         return ClosingIterator(self.dispatch_request(environ, start_response),
                                [local_manager.cleanup])
 
     def dispatch_request(self, environ, start_response):
-        local.application = self
         local.url_adapter = adapter = self.map.bind_to_environ(environ)
         local.request = request = Request(self, environ)
         emit_event('request-start', request)
@@ -223,24 +233,28 @@ class GlashammerApplication(object):
             emit_event('request-end', request)
             response = self.get_view(request, endpoint, values)
         except HTTPException, e:
-            response = e
+            emit_event('request-error', e)
+            response = e.get_response(environ)
         emit_event('response-start', response)
         resp = response(environ, start_response)
-        emit_event('response-end', response)
+        emit_event('response-end', resp)
         return resp
 
     def get_view(self, request, endpoint, values):
+        emit_event('view-dispatch', endpoint, values)
         # try looking up by view first
         view = self.views.get(endpoint)
         if view:
+            emit_event('view-match', view)
             return view(request, **values)
         elif '/' in endpoint:
             # fallback to controller->view
             base, target = endpoint.split('/', 1)
             controller = self.controllers.get(base)
             if controller is not None and hasattr(controller, target):
+                emit_event('controller-match', controller, target)
                 return getattr(controller, target)(request, **values)
-        return NotFound()
+        raise NotFound()
 
     def _ensure_not_finalized(self):
         if self.finalized:
@@ -259,13 +273,13 @@ class GlashammerApplication(object):
         For example, plugin A can load plugin B by importing and adding it's
         setup func like so::
 
-            >>> from a import setup
-            >>> app.add_setup(setup)
+            >>> from a import setup_a
+            >>> app.add_setup(setup_a)
 
         Or in a real example::
 
-            >>> from glashammer.bundles.auth import setup_app
-            >>> app.add_setup(setup_app)
+            >>> from glashammer.bundles.auth import setup_auth
+            >>> app.add_setup(setup_auth)
 
         Will initialize the auth bundle for the application.
         """
@@ -420,14 +434,14 @@ class GlashammerApplication(object):
     def add_shared(self, name, path):
         """
         Add a shared export for name that points to a given path and
-        creates an url rule for <name>/shared that takes a filename
+        creates an url rule for shared/<name> that takes a filename
         parameter.
         """
         self._ensure_not_finalized()
 
         self._shared_exports['/_shared/' + name] = path
         self.add_url('/_shared/%s/<string:filename>' % name,
-                     endpoint=name + '/shared', build_only=True)
+                     endpoint='shared/' + name, build_only=True)
 
     def add_middleware(self, middleware_factory, *args, **kwargs):
         """
@@ -465,8 +479,7 @@ def make_app(setup_func, instance_dir=None, **kw):
     """
     application = local('application')
     application = GlashammerApplication(setup_func,
-        instance_dir, **kw)
-    application = local_manager.make_middleware(application)
+                                        instance_dir, **kw)
     return application
 
 
